package com.gic.haoban.manage.service.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSONObject;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.util.UniqueIdUtils;
import com.gic.haoban.manage.api.dto.StaffActiveDataDTO;
import com.gic.haoban.manage.service.dao.mapper.TabHaobanWxEnterpriseActiveDataMapper;
import com.gic.haoban.manage.service.dao.mapper.fee.TabHaobanQywxFeeOrderAccountMapper;
import com.gic.haoban.manage.service.entity.TabHaobanWxEnterpriseActiveData;
import com.gic.haoban.manage.service.service.WxEnterpriseActiveDataService;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;

/**
 * @description:
 * @Author: wenhua
 * @Date: 2023/2/2 10:44
 */
@Service
public class WxEnterpriseActiveDataServiceImpl implements WxEnterpriseActiveDataService {

    private static final Logger log = LogManager.getLogger(WxEnterpriseActiveDataServiceImpl.class);

    @Autowired
    private TabHaobanWxEnterpriseActiveDataMapper tabHaobanWxEnterpriseActiveDataMapper;

    @Autowired
    private TabHaobanQywxFeeOrderAccountMapper tabHaobanQywxFeeOrderAccountMapper;

    @Override
    public Integer saveOrUpdate(String wxEnterpriseId) {
        if (StrUtil.isBlank(wxEnterpriseId))
            return 0;
        List<HashMap<String, Integer>> feeOrderAccountMapList = tabHaobanQywxFeeOrderAccountMapper.countStatusByWxEnterpriseId(wxEnterpriseId);
        log.info("查询订单表返回的map", JSONObject.toJSONString(feeOrderAccountMapList));
        if (CollUtil.isEmpty(feeOrderAccountMapList)) {
            return 0;
        }
        //初始化各状态
        Integer purchased = 0, used = 0, inactive = 0, transfer = 0, activated = 0, expired = 0;
        for (HashMap<String, Integer> map : feeOrderAccountMapList) {
            switch (map.get("status")) {
                case 1:
                    purchased += map.get("num");
                    inactive += map.get("num");
                    break;
                case 2:
                    purchased += map.get("num");
                    activated += map.get("num");
                    break;
                case 3:
                    purchased += map.get("num");
                    expired += map.get("num");
                    break;
                case 4:
                    purchased += map.get("num");
                    transfer += map.get("num");
                    break;
                case 5:
                    purchased += map.get("num");
                    activated += map.get("num");
                    break;
                default:
                    break;
            }
        }
        //已使用为已购买总数-未使用的
        used = purchased - inactive;
        TabHaobanWxEnterpriseActiveData tabHaobanWxEnterpriseActiveData = tabHaobanWxEnterpriseActiveDataMapper.getWxEnterpriseActiveDataByWxEnterpriseId(wxEnterpriseId);
        if (ObjectUtil.isNotNull(tabHaobanWxEnterpriseActiveData)) {
            //更新
            tabHaobanWxEnterpriseActiveData.setActivated(activated);
            tabHaobanWxEnterpriseActiveData.setPurchased(purchased);
            tabHaobanWxEnterpriseActiveData.setInactive(inactive);
            tabHaobanWxEnterpriseActiveData.setUsed(used);
            tabHaobanWxEnterpriseActiveData.setTransfer(transfer);
            return tabHaobanWxEnterpriseActiveDataMapper.updateActiveDataByWxEnterpriseId(tabHaobanWxEnterpriseActiveData);
        } else {
            //新增
            tabHaobanWxEnterpriseActiveData.setId(UniqueIdUtils.uniqueLong());
            tabHaobanWxEnterpriseActiveData.setWxEnterpriseId(wxEnterpriseId);
            tabHaobanWxEnterpriseActiveData.setActivated(activated);
            tabHaobanWxEnterpriseActiveData.setPurchased(purchased);
            tabHaobanWxEnterpriseActiveData.setInactive(inactive);
            tabHaobanWxEnterpriseActiveData.setUsed(used);
            tabHaobanWxEnterpriseActiveData.setTransfer(transfer);
            return tabHaobanWxEnterpriseActiveDataMapper.insert(tabHaobanWxEnterpriseActiveData);
        }
    }

    @Override
    public StaffActiveDataDTO getWxEnterpriseActiveDataById(String id) {
        if (StrUtil.isBlank(id))
            return null;
        return EntityUtil.changeEntityByJSON(StaffActiveDataDTO.class, tabHaobanWxEnterpriseActiveDataMapper.getWxEnterpriseActiveDataById(id));
    }

    @Override
    public StaffActiveDataDTO getWxEnterpriseActiveDataByWxEnterpriseId(String wxEnterpriseId) {
        if (StrUtil.isBlank(wxEnterpriseId))
            return null;
        return EntityUtil.changeEntityByJSON(StaffActiveDataDTO.class, tabHaobanWxEnterpriseActiveDataMapper.getWxEnterpriseActiveDataById(wxEnterpriseId));
    }
}
